diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index cb819ff818541c725202be9b5dfb80eb53187337..4777c1568ea5a963a278ac18dd9c123c298a0314 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,31 @@
+2003-06-12  Kazu Hirata  <kazu@cs.umass.edu>
+
+	* ChangeLog: Follow spelling conventions.
+	* ChangeLog.2: Likewise.
+	* c-decl.c: Likewise.
+	* cfgloop.h: Likewise.
+	* cgraph.c: Likewise.
+	* coverage.c: Likewise.
+	* cppcharset.c: Likewise.
+	* cpphash.h: Likewise.
+	* cpplex.c: Likewise.
+	* cpplib.c: Likewise.
+	* dbxout.c: Likewise.
+	* df.c: Likewise.
+	* dwarf2out.c: Likewise.
+	* dwarfout.c: Likewise.
+	* emit-rtl.c: Likewise.
+	* explow.c: Likewise.
+	* gcov-io.c: Likewise.
+	* gcov-io.h: Likewise.
+	* gcov.c: Likewise.
+	* gengtype.c: Likewise.
+	* ggc.h: Likewise.
+	* opts.c: Likewise.
+	* real.c: Likewise.
+	* reload.c: Likewise.
+	* stmt.c: Likewise.
+
 2003-06-12  Janis Johnson  <janis187@us.ibm.com>
 
 	* doc/install.texi (m32r-*-elf): Change company to Renesas.
@@ -2420,7 +2448,7 @@ Fri May 23 21:19:31 CEST 2003  Jan Hubicka  <jh@suse.cz>
 
 2003-05-21  Danny Smith  <dannysmith@users.sourceforge.net>
 
-	* gthr-win32.h (__GTHREAD_HIDE_WIN32API): Test for non-zero
+	* gthr-win32.h (__GTHREAD_HIDE_WIN32API): Test for nonzero
 	value, not just if defined.
 	Update copyright year.
 
@@ -5060,7 +5088,7 @@ Mon May 12 11:32:53 CEST 2003  Jan Hubicka  <jh@suse.cz>
 		%call* relocs if generating explicit-reloc PIC.  Don't generate
 		an exception_receiver pattern.
 		(override_options): Initialize mips_got_alias_set.
-		(print_relocation): Remove in favour of...
+		(print_relocation): Remove in favor of...
 		(mips_reloc_string): ...this new function.
 		(print_operand): Handle '%R'.  Use mips_reloc_string.
 		(print_operand_address): Use print_operand to print the symbolic
@@ -6459,7 +6487,7 @@ Sat Apr 19 14:56:17 CEST 2003  Jan Hubicka  <jh@suse.cz>
 2003-04-19  Nathan Sidwell  <nathan@codesourcery.com>
 
 	* doc/invoke.texi (-fprofile-arcs): Mention -lgcov, locking and
-	fork behaviour.
+	fork behavior.
 
 2003-04-19  Neil Booth  <neil@daikokuya.co.uk>
 
@@ -7921,7 +7949,7 @@ Tue Apr  8 11:12:07 CEST 2003  Jan Hubicka  <jh@suse.cz>
 
 	PR c/9516
 	* expr.c (safe_from_p): Rearrange to avoid deep recursion in
-	favour of looping and tail recursion for TREE_LIST and binops.
+	favor of looping and tail recursion for TREE_LIST and binops.
 
 2003-04-08  Zdenek Dvorak  <rakdver@atrey.karlin.mff.cuni.cz>
 
@@ -11463,7 +11491,7 @@ Mon Mar 24 20:03:03 CET 2003  Jan Hubicka  <jh@suse.cz>
 
 	* function.c (STACK_ALIGNMENT_NEEDED): New macro.  Default to 1.
 	(assign_stack_local_1): Perform overall stack alignment only when
-	STACK_ALIGNMENT_NEEDED is non-zero.
+	STACK_ALIGNMENT_NEEDED is nonzero.
 	* doc/tm.texi (STACK_ALIGNMENT_NEEDED): Document.
 
 	* pa.c (compute_frame_size): Rename fsize to size.  Account for
diff --git a/gcc/ChangeLog.2 b/gcc/ChangeLog.2
index 7a624fb4930b3af58131eadc41b1786148214474..39b4f3a0d613aebdc8da70ae38abccd69e4817cf 100644
--- a/gcc/ChangeLog.2
+++ b/gcc/ChangeLog.2
@@ -4782,7 +4782,7 @@ Tue Oct 19 15:26:11 1999  Richard Earnshaw  (rearnsha@arm.com)
 Tue Oct 19 14:01:34 1999  Nick Clifton  <nickc@cygnus.com>
 
 	* toplev.c (main): Do not generate an error message if an
-	unrecognized command line switch is recognisable by another
+	unrecognized command line switch is recognizable by another
 	language.  If extra_warnings are enabled, then generate a
 	warning message instead.
 
@@ -10733,7 +10733,7 @@ Thu Aug 19 11:51:22 EDT 1999  John Wehle  (john@feith.com)
 Thu Aug 19 15:02:01 1999  Nick Clifton  <nickc@cygnus.com>
 
 	* config/rs6000/rs6000.c (rs6000_override_options): Fix test for
-	unrecognisable switches.
+	unrecognizable switches.
 
 Wed Aug 18 23:31:57 1999  J"orn Rennecke <amylaar@cygnus.co.uk>
 
diff --git a/gcc/c-decl.c b/gcc/c-decl.c
index b81ecd8e2b2387dbcbbae3f34c22602a5a6d16f6..ae921d06100c53333f0f3ae6fb7f991b43ffa39e 100644
--- a/gcc/c-decl.c
+++ b/gcc/c-decl.c
@@ -1793,7 +1793,7 @@ pushdecl (x)
 }
 
 /* Record X as belonging to the global scope (C99 "file scope").
-   This is used only internally by the Objective C front end,
+   This is used only internally by the Objective-C front end,
    and is limited to its needs.  It will hork if there is _any_
    visible binding for X (not just a global one).  */
 tree
diff --git a/gcc/cfgloop.h b/gcc/cfgloop.h
index c5db9149c9d96e0d369e0b43f005901a8f080128..0f6b04537a5576b6e446fd399c1504b6c058659c 100644
--- a/gcc/cfgloop.h
+++ b/gcc/cfgloop.h
@@ -144,7 +144,7 @@ struct loop
   /* Loop that is copy of this loop.  */
   struct loop *copy;
 
-  /* Non-zero if the loop is invalid (e.g., contains setjmp.).  */
+  /* Nonzero if the loop is invalid (e.g., contains setjmp.).  */
   int invalid;
 
   /* Auxiliary info specific to a pass.  */
@@ -153,10 +153,10 @@ struct loop
   /* The following are currently used by loop.c but they are likely to
      disappear as loop.c is converted to use the CFG.  */
 
-  /* Non-zero if the loop has a NOTE_INSN_LOOP_VTOP.  */
+  /* Nonzero if the loop has a NOTE_INSN_LOOP_VTOP.  */
   rtx vtop;
 
-  /* Non-zero if the loop has a NOTE_INSN_LOOP_CONT.
+  /* Nonzero if the loop has a NOTE_INSN_LOOP_CONT.
      A continue statement will generate a branch to NEXT_INSN (cont).  */
   rtx cont;
 
diff --git a/gcc/cgraph.c b/gcc/cgraph.c
index fd638bc14fb572f79e336acaf0360e3064b7d123..fd77f663bba6ff2bf717af1da07c1f162ee7429a 100644
--- a/gcc/cgraph.c
+++ b/gcc/cgraph.c
@@ -71,7 +71,7 @@ hash_node (p)
 		       (((struct cgraph_node *) p)->decl));
 }
 
-/* Returns non-zero if P1 and P2 are equal.  */
+/* Returns nonzero if P1 and P2 are equal.  */
 
 static int
 eq_node (p1, p2)
diff --git a/gcc/cppcharset.c b/gcc/cppcharset.c
index 23a44760701cb1a7f406421b745bcf8690eb2012..b11e6424ad80c71ae6f30d65a510c6480d1b1c80 100644
--- a/gcc/cppcharset.c
+++ b/gcc/cppcharset.c
@@ -42,7 +42,7 @@ static int ucn_valid_in_identifier PARAMS ((cpp_reader *, cppchar_t));
    are not part of the relevant standard, or if the string beginning
    at *PSTR doesn't syntactically match the form 'NNNN' or 'NNNNNNNN'.
 
-   Otherwise the non-zero value of the UCN, whether valid or invalid,
+   Otherwise the nonzero value of the UCN, whether valid or invalid,
    is returned.  Diagnostics are emitted for invalid values.  PSTR
    is updated to point one beyond the UCN, or to the syntactically
    invalid character.
diff --git a/gcc/cpphash.h b/gcc/cpphash.h
index 88addeac4d5c5172dd700167cb63ef56379d860a..f6dbb10c18c748d4102b295e833f1a2fb123d768 100644
--- a/gcc/cpphash.h
+++ b/gcc/cpphash.h
@@ -343,7 +343,7 @@ struct cpp_reader
   struct cpp_path *quote_include;	/* "" */
   struct cpp_path *bracket_include;	/* <> */
 
-  /* Multiple include optimisation.  */
+  /* Multiple include optimization.  */
   const cpp_hashnode *mi_cmacro;
   const cpp_hashnode *mi_ind_cmacro;
   bool mi_valid;
diff --git a/gcc/cpplex.c b/gcc/cpplex.c
index e072f01bdcf0ff60103c6c23ebb34986b356efe1..72a5e4d612570d9defaca67237d041bedd75381c 100644
--- a/gcc/cpplex.c
+++ b/gcc/cpplex.c
@@ -192,7 +192,7 @@ warn_in_comment (pfile, note)
 
   /* Within comments we don't warn about trigraphs, unless the
      trigraph forms an escaped newline, as that may change
-     behaviour.  */
+     behavior.  */
   if (note->type != '/')
     return false;
 
@@ -710,7 +710,7 @@ _cpp_lex_token (pfile)
 
       /* Outside a directive, invalidate controlling macros.  At file
 	 EOF, _cpp_lex_direct takes care of popping the buffer, so we never
-	 get here and MI optimisation works.  */
+	 get here and MI optimization works.  */
       pfile->mi_valid = false;
 
       if (!pfile->state.skipping || result->type == CPP_EOF)
diff --git a/gcc/cpplib.c b/gcc/cpplib.c
index 271aa5d487b6ac08825b800c435ac6095d68dc05..bd69642a0b0b37575929dd16bb677b6cbac1a13a 100644
--- a/gcc/cpplib.c
+++ b/gcc/cpplib.c
@@ -1490,7 +1490,7 @@ do_ifndef (pfile)
 
 /* _cpp_parse_expr puts a macro in a "#if !defined ()" expression in
    pfile->mi_ind_cmacro so we can handle multiple-include
-   optimisations.  If macro expansion occurs in the expression, we
+   optimizations.  If macro expansion occurs in the expression, we
    cannot treat it as a controlling conditional, since the expansion
    could change in the future.  That is handled by cpp_get_token.  */
 static void
diff --git a/gcc/dbxout.c b/gcc/dbxout.c
index 7b13e3b84339d2ebfb858162a98f502a9fc1c394..baf473b9006215e7113129a33e069a9283d8f2a6 100644
--- a/gcc/dbxout.c
+++ b/gcc/dbxout.c
@@ -1804,7 +1804,7 @@ dbxout_type (type, full)
     }
 }
 
-/* Return non-zero if the given type represents an integer whose bounds
+/* Return nonzero if the given type represents an integer whose bounds
    should be printed in octal format.  */
 
 static bool
diff --git a/gcc/df.c b/gcc/df.c
index b23c2862b1707a891ee2b61f03be62091b7e166f..25396bd371acc236a93ad82ab66ca640dd2ac447 100644
--- a/gcc/df.c
+++ b/gcc/df.c
@@ -149,7 +149,7 @@ Similarly, should the first entry in the use list be the last use
 4) Working with a sub-CFG.
 
 Often the whole CFG does not need to be analyzed, for example,
-when optimising a loop, only certain registers are of interest.
+when optimizing a loop, only certain registers are of interest.
 Perhaps there should be a bitmap argument to df_analyse to specify
 which registers should be analyzed?
 
@@ -885,7 +885,7 @@ df_ref_record (df, reg, loc, insn, ref_type, ref_flags)
 }
 
 
-/* Return non-zero if writes to paradoxical SUBREGs, or SUBREGs which
+/* Return nonzero if writes to paradoxical SUBREGs, or SUBREGs which
    are too narrow, are read-modify-write.  */
 bool
 read_modify_subreg_p (x)
diff --git a/gcc/dwarf2out.c b/gcc/dwarf2out.c
index dd0ee35b3cab872e800a8358c6c0c7ff34efbf8a..62528b8979a766bbaacef3f1e26a093c899aabef 100644
--- a/gcc/dwarf2out.c
+++ b/gcc/dwarf2out.c
@@ -11291,7 +11291,7 @@ gen_label_die (decl, context_die)
       insn = DECL_RTL (decl);
 
       /* Deleted labels are programmer specified labels which have been
-	 eliminated because of various optimisations.  We still emit them
+	 eliminated because of various optimizations.  We still emit them
 	 here so that it is possible to put breakpoints on them.  */
       if (GET_CODE (insn) == CODE_LABEL
 	  || ((GET_CODE (insn) == NOTE
diff --git a/gcc/dwarfout.c b/gcc/dwarfout.c
index 8555443803eee7b2e198983a34327d3edba1de1a..663bb9fa9a5847d2279eaf4c3cce6af50436cf9d 100644
--- a/gcc/dwarfout.c
+++ b/gcc/dwarfout.c
@@ -3948,7 +3948,7 @@ output_label_die (arg)
       rtx insn = DECL_RTL (decl);
 
       /* Deleted labels are programmer specified labels which have been
-	 eliminated because of various optimisations.  We still emit them
+	 eliminated because of various optimizations.  We still emit them
 	 here so that it is possible to put breakpoints on them.  */
       if (GET_CODE (insn) == CODE_LABEL
 	  || ((GET_CODE (insn) == NOTE
@@ -5741,7 +5741,7 @@ dwarfout_file_scope_decl (decl, set_finalizing)
 	 normal built-in types for the language we are compiling, except
 	 in cases where the types in question are *not* DWARF fundamental
 	 types.  We make an exception in the case of non-fundamental types
-	 for the sake of objective C (and perhaps C++) because the GNU
+	 for the sake of Objective-C (and perhaps C++) because the GNU
 	 front-ends for these languages may in fact create certain "built-in"
 	 types which are (for example) RECORD_TYPEs.  In such cases, we
 	 really need to output these (non-fundamental) types because other
diff --git a/gcc/emit-rtl.c b/gcc/emit-rtl.c
index 208af572c6dd642091191faf050819394691c9e3..03ee0caf75c0e1a0af14f5dc1b866af57ca453c1 100644
--- a/gcc/emit-rtl.c
+++ b/gcc/emit-rtl.c
@@ -351,7 +351,7 @@ reg_attrs_htab_hash (x)
   return ((p->offset * 1000) ^ (long) p->decl);
 }
 
-/* Returns non-zero if the value represented by X (which is really a
+/* Returns nonzero if the value represented by X (which is really a
    reg_attrs *) is the same as that given by Y (which is also really a
    reg_attrs *).  */
 
diff --git a/gcc/explow.c b/gcc/explow.c
index ec7a69a783366985eec5612d1e20f52fc95bc942..cd0a15836a3643bb51fbf95bf98734a0cec3dcd7 100644
--- a/gcc/explow.c
+++ b/gcc/explow.c
@@ -663,7 +663,7 @@ maybe_set_unchanging (ref, t)
      contents of the initializer.  Yes, this does eliminate a good fraction
      of the number of uses of RTX_UNCHANGING_P for a language like Ada.
      It also eliminates a good quantity of bugs.  Let this be incentive to
-     eliminate RTX_UNCHANGING_P entirely in favour of a more reliable
+     eliminate RTX_UNCHANGING_P entirely in favor of a more reliable
      solution, perhaps based on alias sets.  */
 
   if ((TREE_READONLY (t) && DECL_P (t)
diff --git a/gcc/gcov.c b/gcc/gcov.c
index 4c92170ebbf282894e06f27de79fea93b10ff340..fd18c007356f7a4dd947139c0f0c68ad729cbc7c 100644
--- a/gcc/gcov.c
+++ b/gcc/gcov.c
@@ -1745,7 +1745,7 @@ accumulate_line_counts (src)
     }
 }
 
-/* Ouput information about ARC number IX.  Returns non-zero if
+/* Ouput information about ARC number IX.  Returns nonzero if
    anything is output.  */
 
 static int
diff --git a/gcc/gengtype.c b/gcc/gengtype.c
index 52e8780f492a0d36dea54ee5f533b6e80ce0ed53..0e58dc0c717c8d6dcd6c31774dbf8f02fdb16f5c 100644
--- a/gcc/gengtype.c
+++ b/gcc/gengtype.c
@@ -1654,7 +1654,7 @@ walk_type (type_p t, struct walk_type_data *d)
 	const char *oldval = d->val;
 	char *newval;
 
-	/* If it's an array of scalars, we optimise by not generating
+	/* If it's an array of scalars, we optimize by not generating
 	   any code.  */
 	if (t->u.a.p->kind == TYPE_SCALAR)
 	  break;
diff --git a/gcc/ggc.h b/gcc/ggc.h
index 2f7d09c3d6f74c8bf7a07670afa06964da261597..e2a76e53946409cb61089cbd4800e9b81f2f7d22 100644
--- a/gcc/ggc.h
+++ b/gcc/ggc.h
@@ -103,7 +103,7 @@ extern const struct ggc_cache_tab * const gt_ggc_cache_rtab[];
 
 /* Actually set the mark on a particular region of memory, but don't
    follow pointers.  This function is called by ggc_mark_*.  It
-   returns zero if the object was not previously marked; non-zero if
+   returns zero if the object was not previously marked; nonzero if
    the object was already marked, or if, for any other reason,
    pointers in this data structure should not be traversed.  */
 extern int ggc_set_mark	(const void *);
diff --git a/gcc/opts.c b/gcc/opts.c
index 25dacf2131d27f6abf7ac01430ba9bf358418f3b..83561b2679f45fde036f11a631e2c4dbfd9d3914 100644
--- a/gcc/opts.c
+++ b/gcc/opts.c
@@ -163,7 +163,7 @@ handle_option (int argc ATTRIBUTE_UNUSED, char **argv, int lang_mask)
       if (!on && (option->flags & CL_REJECT_NEGATIVE))
 	goto done;
 
-      /* We've recognised this switch.  */
+      /* We've recognized this switch.  */
       result = 1;
 
       /* Sort out any argument the switch takes.  */
diff --git a/gcc/real.c b/gcc/real.c
index 4a4b04012ce04ab6f37dcf19f843d0d37cabd0d5..4e1dc227f12e4eb7a6d2f782305c63d38a66e716 100644
--- a/gcc/real.c
+++ b/gcc/real.c
@@ -2281,7 +2281,7 @@ real_nan (r, str, quiet, mode)
 }
 
 /* Fills R with the largest finite value representable in mode MODE.
-   If SIGN is non-zero, R is set to the most negative finite value.  */
+   If SIGN is nonzero, R is set to the most negative finite value.  */
 
 void
 real_maxval (r, sign, mode)
@@ -3033,7 +3033,7 @@ const struct real_format mips_double_format =
 
 
 /* IEEE extended double precision format.  This comes in three
-   flavours: Intel's as a 12 byte image, Intel's as a 16 byte image,
+   flavors: Intel's as a 12 byte image, Intel's as a 16 byte image,
    and Motorola's.  */
 
 static void encode_ieee_extended PARAMS ((const struct real_format *fmt,
diff --git a/gcc/reload.c b/gcc/reload.c
index 5a82d995a2c2e6e4c306a2929742291cb8c97b4b..7ab823db6058c29f5ceb1e3ecc928bdfb99d8734 100644
--- a/gcc/reload.c
+++ b/gcc/reload.c
@@ -4887,7 +4887,7 @@ find_reloads_address (mode, memrefloc, ad, loc, opnum, type, ind_levels, insn)
      of it.
 
      Handle all base registers here, not just fp/ap/sp, because on some
-     targets (namely Sparc) we can also get invalid addresses from preventive
+     targets (namely SPARC) we can also get invalid addresses from preventive
      subreg big-endian corrections made by find_reloads_toplev.
 
      If we decide to do something, it must be that `double_reg_address_ok'
diff --git a/gcc/stmt.c b/gcc/stmt.c
index 4561d722230ba935c7147fe802f92735ba1a7b40..1bf70f8d6a7e1096609accb0d401c60d0ecde556 100644
--- a/gcc/stmt.c
+++ b/gcc/stmt.c
@@ -5592,7 +5592,7 @@ expand_end_case_type (orig_index, orig_type)
 	      /* For constant index expressions we need only
 		 issue an unconditional branch to the appropriate
 		 target code.  The job of removing any unreachable
-		 code is left to the optimisation phase if the
+		 code is left to the optimization phase if the
 		 "-O" option is specified.  */
 	      for (n = thiscase->data.case_stmt.case_list; n; n = n->right)
 		if (! tree_int_cst_lt (index_expr, n->low)
diff --git a/gcc/coverage.c b/gcc/coverage.c
index 1b537c621ebabe72f02721350aacaaf0deb6f3e5..9f33b811605e7beeb4531389264368e3345a1160 100644
--- a/gcc/coverage.c
+++ b/gcc/coverage.c
@@ -340,7 +340,7 @@ get_coverage_counts (unsigned counter, unsigned expected,
   return entry->counts;
 }
 
 /* Allocate NUM counters of type COUNTER. Returns non-zero if the
    allocation succeeded.  */
 
 int
@@ -426,7 +426,7 @@ compute_checksum ()
 
 /* Begin output to the graph file for the current function.
    Opens the output file, if not already done. Writes the
-   function header, if not already done. Returns non-zero if data
+   function header, if not already done. Returns nonzero if data
    should be output.  */
 
 int
@@ -340,7 +340,7 @@ get_coverage_counts (unsigned counter, unsigned expected,
 }
 
-/* Allocate NUM counters of type COUNTER. Returns non-zero if the
+/* Allocate NUM counters of type COUNTER. Returns nonzero if the
    allocation succeeded.  */
 
diff --git a/gcc/gcov-io.c b/gcc/gcov-io.c
index 94197c962e62c418250738c7ad2f328acd30dd13..112e77caa77a34bf36f59f8460a038f02edb9c8a 100644
--- a/gcc/gcov-io.c
+++ b/gcc/gcov-io.c
@@ -313,7 +313,7 @@ gcov_write_tag_length (gcov_unsigned_t tag, gcov_unsigned_t length)
   return;
 }
 
 /* Write a summary structure to the gcov file.  Return non-zero on
    overflow.  */
 
 GCOV_LINKAGE void
@@ -489,7 +489,7 @@ gcov_sync (gcov_position_t base, gcov_unsigned_t length)
 
 #if IN_LIBGCOV
 /* Move to the a set position in a gcov file.  BASE is zero to move to
-   the end, and non-zero to move to that position. */
+   the end, and nonzero to move to that position. */
 
 GCOV_LINKAGE void
 gcov_seek (gcov_position_t base)
@@ -313,7 +313,7 @@ gcov_write_tag_length (gcov_unsigned_t tag, gcov_unsigned_t length)
 }
 
-/* Write a summary structure to the gcov file.  Return non-zero on
+/* Write a summary structure to the gcov file.  Return nonzero on
    overflow.  */
 
diff --git a/gcc/gcov-io.h b/gcc/gcov-io.h
index e6cf94e6ac26b67adce54a59f60a3f6c00f229ad..e512783e89dc3c5f09899a14cc76e211b843883f 100644
--- a/gcc/gcov-io.h
+++ b/gcc/gcov-io.h
@@ -147,8 +147,8 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 
    This file is included by both the compiler, gcov tools and the
    runtime support library libgcov. IN_LIBGCOV and IN_GCOV are used to
-   distinguish which case is which.  If IN_LIBGCOV is non-zero,
-   libgcov is being built. If IN_GCOV is non-zero, the gcov tools are
+   distinguish which case is which.  If IN_LIBGCOV is nonzero,
+   libgcov is being built. If IN_GCOV is nonzero, the gcov tools are
    being built. Otherwise the compiler is being built. IN_GCOV may be
    positive or negative. If positive, we are compiling a tool that
    requires additional functions (see the code for knowledge of what
@@ -480,7 +480,7 @@ gcov_position (void)
   return gcov_var.start + gcov_var.offset;
 }
 
 /* Return non-zero if we read to end of file.  */
 
 static inline int
 gcov_is_eof ()
@@ -488,7 +488,7 @@ gcov_is_eof ()
   return !gcov_var.overread;
 }
 
 /* Return non-zero if the error flag is set.  */
 
 static inline int
 gcov_is_error ()
@@ -480,7 +480,7 @@ gcov_position (void)
 }
 
-/* Return non-zero if we read to end of file.  */
+/* Return nonzero if we read to end of file.  */
 
 static inline int
@@ -488,7 +488,7 @@ gcov_is_eof ()
 }
 
-/* Return non-zero if the error flag is set.  */
+/* Return nonzero if the error flag is set.  */
 
 static inline int